from enum import Enum


class EFaseRetificacao(Enum):
    NaoIniciado = 0
    SolicitacaoXml = 1
    AguardandoXml = 2
    DownloadXml = 3
    ExtraindoDadosDoXml = 4
    AguardandoRubrica = 5
    AberturaDeCompetencia = 6
    ConsultandoESocialAberturaCompetencia = 7
    InclusaoDasRubricas = 8
    ConsultandoESocialInclusaoRubricas = 9
    ExclusaoDePagamentos = 10
    ConsultandoESocialExclusaoPagamentos = 11
    RetificacaoDaRemuneracao = 12
    ConsultandoESocialRetificacaoRemuneracao = 13
    InclusaoDosPagamentos = 14
    ConsultandoESocialInclusaoPagamentos = 15
    Desligamento = 16
    ConsultandoESocialDesligamento = 17
    FechamentoDeCompetencia = 18
    ConsultandoESocialFechamentoCompetencia = 19
    Finalizado = 20



import httpx

class RequestServicoApi:
    def __init__(self, url, token):
        self.url = url
        self.token = token

    async def handler(self, *, mensagem_atualizacao: dict):
        async with httpx.AsyncClient(timeout=120, verify=False) as client:
            print(self.token)
            response = await client.post(self.url, json=mensagem_atualizacao)

            if response.status_code != 200:
                raise Exception(f"Erro ao fazer request ao servico de API: {response.status_code}")
            
            return response.json()